@@ -353,6 +353,7 @@ enum GameResultInner {
     FlatBlack,
     OtherWhite,
     OtherBlack,
+    OtherDecisive,
     Draw,
 }
 
@@ -715,6 +716,9 @@ impl FromStr for Message {
                                 Duration::from_millis(token()?.parse()?),
                             ),
                             "Over" => Message::GameOver(id, token()?.parse()?),
+                            "Abandoned." => {
+                                Message::GameOver(id, GameResult(GameResultInner::OtherDecisive))
+                            }
                             move_type @ ("P" | "M") => {
                                 let square = token()?.to_ascii_lowercase().parse()?;
                                 Message::Play(
